@@ -23,6 +23,8 @@ typedef struct _lj_config {
   char *customsecurity; /*  A single string like "thisgroup:thatgroup:etc" */
   char *userpic; /*  A word that */
   char *music; /* a string describing the song/sounds being listened to */
+  char *location; /* a string describing the current location */
+  char *taglist; /* a comma-separated string of relevant tags */
   u_int32_t allowmask; /* set bit 0 for friends only  */
   int nocomments; /* prop_opt_nocomments */
   int preformatted; /* prop_opt_preformatted */
