@@ -52,6 +52,8 @@ typedef struct _lj_event {
   char *mood;
   char *userpic;
   char *music;
+  char *location;
+  char *taglist;
   int  moodid;
   char dateback[13];
   int  nocomments;
