@@ -6,6 +6,6 @@
 
 extern FILE *getconn(const char *host, int port);
 extern void closeconn(FILE *conn);
-extern void lj_send_request(const lj_server *serverinfo, const lj_user *user, char *request, hashtable *lj_hash);
+extern void lj_send_request(const lj_server *serverinfo, const lj_user *user, const char *request, hashtable *lj_hash);
 
 #endif
