@@ -64,9 +64,10 @@ main(int argc, char **argv)
 
 #ifdef		HAVE_ICONV
 	utfenc = iconv_open("UTF-8", config.charset);
-	if ((iconv_t)-1 == utfenc)
+	utfdec = iconv_open(config.charset, "UTF-8");
+	if ((iconv_t)-1 == utfenc || (iconv_t)-1 == utfdec)
 		lj_error("Cannot open character conversion\n");
-	lj_debug(2, "input charset: [%s]\n", config.charset);
+	lj_debug(2, "local charset: [%s]\n", config.charset);
 #endif		/* HAVE_ICONV */
 
 
@@ -111,23 +112,17 @@ main(int argc, char **argv)
 	}
 	else
 	{
-		puts("Logging on to LiveJournal, please wait");
+		printf("Logging on to %s, please wait\n", server.hostname);
 		if (lj_login(&server, &user, &logininfo))
 		{
 			/* if this returns a non - zero value
 			 * we know something broke
 			 */
-			if ((logininfo.errmsg != NULL)
-				    && !strcmp(logininfo.errmsg, ""))
-			{
-				fprintf(stderr, "Errors logging in:\n\t%s\n",
+			if (logininfo.errmsg)
+				lj_error("Errors logging in:\n\t%s\n",
 					logininfo.errmsg);
-				exit(1);
-			}
 			else
-			{
 				lj_error("Errors logging in, try again later\n");
-			}
 		}
 		else
 		{
@@ -289,24 +284,21 @@ main(int argc, char **argv)
 		int             i = 0;
 
 		if ((i = atoi(post.usejournal)))
-		{
 			post.usejournal = user.access[i];
-		}
 
 		for (i = 0; i < user.accesscount; i++)
 			if (!strcmp(post.usejournal, user.access[i]))
 				break;
 		if (i >= user.accesscount)
-		{
-			fprintf(stderr, "You don't have access to post in %s!\n",
+			lj_error("You don't have access to post in %s!\n",
 				post.usejournal);
-			exit(1);
-		}
 	}
 
 	post.nocomments = config.nocomments;
 	post.preformatted = config.preformatted;
 	post.music = config.music;
+	post.location = config.location;
+	post.taglist = config.taglist;
 	if (config.backdated)
 	{
 		post.backdated = config.backdated;
@@ -465,6 +457,18 @@ main(int argc, char **argv)
 					free(post.mood);
 				post.mood = strdup(colon);
 			}
+			else if (!strcasecmp("Location", start))
+			{
+				if (post.location)
+					free(post.location);
+				post.location = strdup(colon);
+			}
+			else if (!strcasecmp("Taglist", start))
+			{
+				if (post.taglist)
+					free(post.taglist);
+				post.taglist = strdup(colon);
+			}
 			else
 			{
 				printf("Ignoring unknown header %s\n", start);
