@@ -18,7 +18,8 @@ lj_usage(void)
 {
   puts (
  "Usage: clive [ -u username ] [ -w password ] [ -j journal ] [ -s subject ]\n"
- "             [ -r security ] [ -f mood ] [ -i userpic ] [ -m music ] [-p] [-d]\n"
+ "             [ -r security ] [ -f mood ] [ -i userpic ] [ -m music ]\n"
+ "             [ -l location ] [ -t taglist] [-p] [-d]\n"
  "             [ --backdate YYYMMDDhhmm ] [ --replace itemid ]\n"
  "             [ --charset encoding]\n"
  "             [ --plainpass ] [ --hashpass ] [ --softreturn ]\n"
@@ -32,79 +33,43 @@ int
 lj_init_config(int argc, char **argv, lj_config * config)
 {
 	int		c, optindex;
-	static struct option longopts[] = {
-		{"config", required_argument, 0, 'c'},
-		{"nocomments", no_argument, 0, 'd'},
-		{"mood", required_argument, 0, 'f'},
-		{"userpic", required_argument, 0, 'i'},
-		{"usejournal", required_argument, 0, 'j'},
-		{"music", required_argument, 0, 'm'},
-		{"preformat", no_argument, 0, 'p'},
-		{"security", required_argument, 0, 'r'},
-		{"subject", required_argument, 0, 's'},
-		{"username", required_argument, 0, 'u'},
-		{"password", required_argument, 0, 'w'},
-		{"help", no_argument, 0, '?'},
-		{"version", no_argument, 0, 'v'},
-		{"plainpass", no_argument, 0, 1},	/* config->plainpass */
-		{"hashpass", no_argument, 0, 1},	/* config->hashpass */
-		{"backdate", required_argument, 0, 0}, 	/* config->backdated */
-		{"nologin", no_argument, 0, 1}, 	/* config->nologin */
-		{"loginonly", no_argument, 0, 1}, 	/* config->loginonly */
-		{"lfrgp", no_argument, 0, 1}, 		/* config->listfrgp */
-		{"laccess", no_argument, 0, 1}, 	/* config->listaccess */
-		{"lpic", no_argument, 0, 1},
-		{"lfriends", no_argument, 0, 1},
-		{"levents", optional_argument, 0, 1},
-		{"lcomments", optional_argument, 0, 1},
-		{"replace", required_argument, 0, 1},
-		{"addfriend", required_argument, 0, 1},
-		{"delfriend", required_argument, 0, 1},
-		{"softreturn", no_argument, 0, 1},
-		{"charset", required_argument, 0, 0},
-		{NULL, 0, 0, 0},
+	struct option longopts[] = {
+		{"config",	required_argument, NULL, 'c'},	// 0
+		{"nocomments",	no_argument,       NULL, 'd'},
+		{"debug",	optional_argument, NULL, 'D'},
+		{"mood",	required_argument, NULL, 'f'},
+		{"userpic",	required_argument, NULL, 'i'},
+		{"usejournal",	required_argument, NULL, 'j'},
+		{"location",	required_argument, NULL, 'l'},
+		{"music",	required_argument, NULL, 'm'},
+		{"preformat",	no_argument,       NULL, 'p'},
+		{"security",	required_argument, NULL, 'r'},
+		{"subject",	required_argument, NULL, 's'},
+		{"taglist",	required_argument, NULL, 't'},
+		{"username",	required_argument, NULL, 'u'},
+		{"version",	no_argument,       NULL, 'v'},
+		{"password",	required_argument, NULL, 'w'},
+		{"plainpass",	no_argument,       &config->plainpass,	1},// 17
+		{"hashpass",	no_argument,       &config->hashpass,	1},
+		{"nologin",	no_argument,       &config->nologin,	1},
+		{"loginonly",	no_argument,       &config->loginonly,	1},
+		{"lfrgp",	no_argument,       &config->lfrgp,	1},
+		{"laccess",	no_argument,       &config->laccess,	1},
+		{"lpic",	no_argument,       &config->lpic,	1},
+		{"lfriends",	no_argument,       &config->lfriends,	1},
+		{"softreturn",	no_argument,       &config->softreturn, 1},
+		{"addfriend",	required_argument, NULL, -'a'},
+		{"backdate",	required_argument, NULL, -'b'},
+		{"lcomments",	optional_argument, NULL, -'c'},
+		{"delfriend",	required_argument, NULL, -'d'},
+		{"charset",	required_argument, NULL, -'C'},
+		{"levents",	optional_argument, NULL, -'e'},
+		{"help",	no_argument,       NULL, -'h'},
+		{"replace",	required_argument, NULL, -'r'},
+		{NULL, 0, NULL, 0},
 	};
 
-	/* When making changes to the above predefined array,
-	 * be sure to fix any index changes here
-	 */
-	longopts[13].flag = &(config->plainpass);
-	longopts[14].flag = &(config->hashpass);
-	longopts[16].flag = &(config->nologin);
-	config->nologin = 0;	/* we default to logging in */
-	longopts[17].flag = &(config->loginonly);
-	config->loginonly = 0;	/* we default to also posting */
-	longopts[18].flag = &(config->lfrgp);
-	config->lfrgp = 0;	/* normally we 'll post */
-	longopts[19].flag = &(config->laccess);
-	config->laccess = 0;
-	longopts[20].flag = &(config->lpic);
-	config->lpic = 0;
-	longopts[21].flag = &(config->lfriends);
-	config->lfriends = 0;
-	longopts[22].flag = &(config->levents);
-	config->levents = 0;
-	longopts[23].flag = &(config->lcomments);
-	config->lcomments = 0;
-	longopts[24].flag = &(config->replace);
-	config->replace = 0;
-	longopts[25].flag = &(config->addfriend);
-	config->addfriend = 0;
-	longopts[26].flag = &(config->delfriend);
-	config->delfriend = 0;
-	longopts[27].flag = &(config->softreturn);
-	config->softreturn = 0;
-
-	config->username = config->password = config->usejournal =
-		config->subject = config->server_host = config->server_path =
-		config->mood = config->userpic = config->editor =
-		config->rcfile = config->customsecurity = config->music =
-		config->charset = NULL;
-	config->plainpass = config->hashpass = config->security = config->allowmask =
-		config->nocomments = config->preformatted = config->backdated =
-		config->server_port = config->getmoods = config->getmenus =
-		config->getpickws = 0;
-	config->dateback[0] = '\0';
+	memset(config, 0, sizeof(lj_config));
 
 	lj_debug(3, "Getting command-line parameters");
 	lj_debug(3, "argc: [%d]\n", argc);
@@ -112,57 +77,48 @@ lj_init_config(int argc, char **argv, lj_config * config)
 	 * when you add options to the array above that have single character
 	 * equivalents, be sure to add them to this string here.
 	 */
-	while ((c = getopt_long(argc, (char **)argv, "c:df:i:j:m:pr:s:u:vw:?",
-		longopts, &optindex)) >= 0)
+	while ((c = getopt_long(argc, (char **)argv, "c:dD:f:i:j:l:m:pr:s:t:u:vw:?",
+		longopts, &optindex)) != -1)
 	{
 		switch (c)
 		{
+		/* Regular long options */
 		case 0:
-		/*
-		 * these are our long options, and so we switch again
-		 * when making changes to the predefined array, make
-		 * sure to fix the numbers so they match the proper
-		 * indexes here
-		 */
-			switch (optindex)
-			{
-			case 15:
-				if (strlen(optarg) == 12)
-				{
-					config->backdated++;
-					lj_strcopy(config->dateback, optarg);
-				}
-				else
-				{
-					lj_error("Invalid date string. "
-						"Date format YYYYMMDDhhmm\n");
-				}
-				lj_debug(2, "Backdating entry [%s]\n",
-					config->dateback);
-				break;
-			case 20:
-				config->getpickws++;
-				break;
-			case 22:
-				if (optarg)
-					config->levents = atoi(optarg);
-				break;
-			case 23:
-				if (optarg)
-					config->lcomments = atoi(optarg);
-				break;
-			case 24:
-				config->replace = atoi(optarg);
-				break;
-			case 25:
-			case 26:
-				config->editfriend = strdup(optarg);
-				break;
-			case 28:
-				lj_set_config(config, "charset", optarg);
-				break;
-			}
 			break;
+		/* Special long options */
+		case -'a':
+			config->addfriend = 1;
+			lj_strcopy(config->editfriend, optarg);
+			break;
+		case -'b':
+			config->backdated = 1;
+			if (strlen(optarg) == 12)
+				lj_strcopy(config->dateback, optarg);
+			else
+				lj_error("Invalid date string. "
+					"Date format YYYYMMDDhhmm\n");
+			lj_debug(2, "Backdated entry [%s]\n", config->dateback);
+			break;
+		case -'c':
+			config->lcomments = optarg ? atoi(optarg) : 5;
+			break;
+		case -'C':
+			lj_strcopy(config->charset, optarg);
+			break;
+		case -'d':
+			config->delfriend = 1;
+			lj_strcopy(config->editfriend, optarg);
+			break;
+		case -'e':
+			config->levents = optarg ? atoi(optarg) : 5;
+			break;
+		case -'h':
+			lj_usage();
+			exit(0);
+		case -'r':
+			config->replace = atoi(optarg);
+			break;
+		/* Regular options (short + long) */
 		case 'c':
 			lj_set_config(config, "rcfile", optarg);
 			break;
@@ -170,6 +126,13 @@ lj_init_config(int argc, char **argv, lj_config * config)
 			config->nocomments++;
 			lj_debug(2, "Comments disabled");
 			break;
+		case 'D':
+			if (optarg)
+				debug_level = atoi(optarg);
+			if (!debug_level)
+				debug_level = 1;
+			lj_debug(2, "Enabling debug (level %d)", debug_level);
+			break;
 		case 'f':
 			lj_set_config(config, "mood", optarg);
 			break;
@@ -180,6 +143,9 @@ lj_init_config(int argc, char **argv, lj_config * config)
 		case 'j':
 			lj_set_config(config, "usejournal", optarg);
 			break;
+		case 'l':
+			lj_set_config(config, "location", optarg);
+			break;
 		case 'm':
 			lj_set_config(config, "music", optarg);
 			break;
@@ -193,6 +159,9 @@ lj_init_config(int argc, char **argv, lj_config * config)
 		case 's':
 			lj_set_config(config, "subject", optarg);
 			break;
+		case 't':
+			lj_set_config(config, "taglist", optarg);
+			break;
 		case 'u':
 			lj_set_config(config, "username", optarg);
 			break;
@@ -202,9 +171,19 @@ lj_init_config(int argc, char **argv, lj_config * config)
 		case 'w':
 			lj_set_config(config, "password", optarg);
 			break;
-		case '?':
+		/* errors */
+		case ':':
+			fprintf(stderr, "Missing option argument\n\n");
 			lj_usage();
-			exit(0);
+			exit(1);
+		case '?':
+			fprintf(stderr, "Ambiguous option selected\n\n");
+			lj_usage();
+			exit(1);
+		default:
+			fprintf(stderr, "Invalid option '%c'\n\n", c);
+			lj_usage();
+			exit(1);
 		}
 	}
 	lj_debug(3, "Got command line options");
@@ -219,9 +198,9 @@ lj_init_config(int argc, char **argv, lj_config * config)
 	lj_set_config(config, "editor", getenv("EDITOR"));
 	lj_set_config(config, "editor", getenv("VISUAL"));
 	lj_set_config(config, "server_host", "www.livejournal.com");
+	lj_set_config(config, "server_port", "80");
 	lj_set_config(config, "server_path", "/interface/flat");
-	lj_set_config(config, "charset", "ISO-8859-1");
-	config->server_port = 80;
+	lj_set_config(config, "charset", ""); /* "" = "char" = local charset */
 	lj_ask_username(config);
 	return 0;
 }
@@ -273,6 +252,14 @@ lj_set_config(lj_config * config, const char * const key, const char * const val
 			lj_debug(2, "%s: [%s]\n", key, config->server_host);
 		}
 	}
+	else if (!strcmp(key, "server_port"))
+	{
+		if (!config->server_port)
+		{
+			config->server_port = atoi(value);
+			lj_debug(2, "%s: [%d]\n", key, config->server_port);
+		}
+	}
 	else if (!strcmp(key, "server_path"))
 	{
 		if ((config->server_path == NULL)
@@ -300,8 +287,6 @@ lj_set_config(lj_config * config, const char * const key, const char * const val
 	}
 	else if (!strcmp(key, "security"))
 	{
-		int             i = 0;
-
 		if (value[0] == ':' &&
 			((config->customsecurity == NULL) ||
 			 !strcmp(config->customsecurity, "")))
@@ -309,7 +294,7 @@ lj_set_config(lj_config * config, const char * const key, const char * const val
 			/* custom security */
 			config->customsecurity = strdup(value);
 		}
-		else if (!strcmp(value, "private"))
+		else if (!strcmp(value, "private") || !strcmp(value, "1"))
 		{
 			/*
 			 * do not confuse the number for value with the
@@ -318,35 +303,11 @@ lj_set_config(lj_config * config, const char * const key, const char * const val
 			 */
 			config->security = 1;
 		}
-		else if (!strcmp(value, "friends"))
+		else if (!strcmp(value, "friends") || !strcmp(value, "2"))
 		{
 			config->security = 2;	/* usemask */
 			config->allowmask = 1;
 		}
-		else if ((i = atoi(optarg)))
-		{
-			char            buff[64];
-
-			sprintf(buff, "%d", i);
-			if (strlen(buff) == strlen(optarg))
-			{
-				switch (i)
-				{
-				case 1:	/* private */
-					config->security = 1;
-					break;
-				case 2:	/* friends */
-					config->security = 2;
-					config->allowmask = 1;
-					break;
-				default:
-					lj_error("Invalid security setting. . . exiting\n");
-					break;
-				}
-			}
-			else
-				lj_error("Invalid security setting. . . exiting\n");
-		}
 		else
 			lj_error("Invalid security setting. . . exiting\n");
 		if (config->customsecurity)
@@ -386,6 +347,22 @@ lj_set_config(lj_config * config, const char * const key, const char * const val
 			lj_debug(2, "music: [%s]\n", config->music);
 		}
 	}
+	else if (!strcmp(key, "location"))
+	{
+		if ((config->location == NULL) || !strcmp(config->location, ""))
+		{
+			config->location = strdup(value);
+			lj_debug(2, "location: [%s]\n", config->location);
+		}
+	}
+	else if (!strcmp(key, "taglist"))
+	{
+		if ((config->taglist == NULL) || !strcmp(config->taglist, ""))
+		{
+			config->taglist = strdup(value);
+			lj_debug(2, "taglist: [%s]\n", config->taglist);
+		}
+	}
 	else if (!strcmp(key, "softreturn"))
 	{
 		if (!strcasecmp(value, "true") ||
