@@ -36,6 +36,7 @@ lj_login(const lj_server * const serverinfo, lj_user *user, lj_logininfo *logini
 
 		logininfo->success = 1;
 		get(lj_hash, &value, "success");
+		lj_debug(2, "success [%s]", value);
 		if (!value || strcmp(value, "OK"))
 		{
 			/* we failed */
@@ -55,7 +56,7 @@ lj_login(const lj_server * const serverinfo, lj_user *user, lj_logininfo *logini
 
 	/* now we look for access groups */
 	geti(lj_hash, &user->accesscount, "access_count");
-	user->access = (char **) lj_malloc((size_t)user->accesscount);
+	user->access = (char **) lj_malloc(sizeof(char *) * (size_t)user->accesscount);
 	for (i = 0; i < user->accesscount; i++)
 	{
 		getp(lj_hash, &user->access[i], "access_%d", i + 1);
@@ -64,7 +65,7 @@ lj_login(const lj_server * const serverinfo, lj_user *user, lj_logininfo *logini
 
 	/* next we get friend groups */
 	geti(lj_hash, &user->frgrpcount, "frgrp_maxnum");
-	user->frgrps = (char **) lj_malloc((size_t)user->frgrpcount);
+	user->frgrps = (char **) lj_malloc(sizeof(char *) * (size_t)user->frgrpcount);
 	for (i = 0; i < user->frgrpcount; i++)
 	{
 		getp(lj_hash, &(user->frgrps[i]), "frgrp_%d_name", i + 1);
@@ -73,7 +74,7 @@ lj_login(const lj_server * const serverinfo, lj_user *user, lj_logininfo *logini
 
 	/* next we find our mood ID */
 	geti(lj_hash, &user->moodcount, "mood_count");
-	user->moods = (char **) lj_malloc((size_t)user->moodcount);
+	user->moods = (char **) lj_malloc(sizeof(char *) * (size_t)user->moodcount);
 	for (i = 0; i < user->moodcount; i++)
 	{
 		getp(lj_hash, &(user->moods[i]), "mood_%d_name", i + 1);
