@@ -12,13 +12,15 @@
 #include <errno.h>
 #include <netdb.h>
 #include <netinet/in.h>
+#include <iconv.h>
 
 FILE *
 getconn(const char *host, int port)
 {
 	int			sockfd;
 	struct hostent *	server;
-	struct sockaddr_in	server_addr;
+	struct sockaddr_in	server_addr = { .sin_family = AF_INET };
+	FILE *			stream;
 
 	/*
 	 * resolve the domain name
@@ -41,7 +43,6 @@ getconn(const char *host, int port)
 	/*
 	 * If we've gotten this far, we go ahead and make our sockaddr...
 	 */
-	server_addr.sin_family = AF_INET;
 	server_addr.sin_port = htons(port);
 	memcpy(&server_addr.sin_addr.s_addr, server->h_addr, server->h_length);
 
@@ -55,10 +56,14 @@ getconn(const char *host, int port)
 		perror("Error connecting to host");
 		return NULL;
 	}
+
 	/*
 	 * Will return a FILE * value if successful, will return NULL if not
 	 */
-	return fdopen(sockfd, "r+");
+	if ((stream = fdopen(sockfd, "r+")))
+		setlinebuf(stream);
+
+	return stream;
 }
 
 void
@@ -75,10 +80,12 @@ closeconn(FILE *conn)
  * Description:	sends a request to lj server and stores the result in hash
  */
 void
-lj_send_request(const lj_server * const serverinfo, const lj_user * const user, char *request, hashtable *lj_hash)
+lj_send_request(const lj_server * const serverinfo, const lj_user * const user, const char * const request, hashtable *lj_hash)
 {
 	FILE	*conn;
-	char	key[LJ_BUFFER_MAX], value[LJ_BUFFER_MAX];
+	char	key[LJ_BUFFER_MAX],
+		value[LJ_BUFFER_MAX],
+		decoded[LJ_BUFFER_MAX];
 
 	if (!user->username || !user->password)
 		lj_error("You must supply a username and password!\n");
@@ -91,6 +98,8 @@ lj_send_request(const lj_server * const serverinfo, const lj_user * const user,
 		"Sending to the server:\n"
 		"POST %s HTTP/1.0\r\n"
 		"Host: %s\r\n"
+		"User-Agent: POSIX-Clive/" VERSION "\r\n"
+		"Connection: close\r\n"
 		"Content-type: application/x-www-form-urlencoded\r\n"
 		"Content-length: %d\r\n\r\n%s",
 		serverinfo->path,
@@ -100,8 +109,10 @@ lj_send_request(const lj_server * const serverinfo, const lj_user * const user,
 	fprintf(conn,
 		"POST %s HTTP/1.1\r\n"
 		"Host: %s\r\n"
+		"User-Agent: POSIX-Clive/" VERSION "\r\n"
+		"Connection: close\r\n"
 		"Content-type: application/x-www-form-urlencoded\r\n"
-		"Content-length: %d\r\n\r\n%s",
+		"Content-length: %zu\r\n\r\n%s",
 		serverinfo->path,
 		serverinfo->hostname,
 		strlen(request),
@@ -116,13 +127,14 @@ lj_send_request(const lj_server * const serverinfo, const lj_user * const user,
 	 */
 	while (fgets(key, LJ_BUFFER_MAX, conn) && strcmp(key, "\r\n"))
 	{
-#ifdef DEBUG3
-		int             i = strlen(key);
+		if (debug_level >= 3)
+		{
+			int             i = strlen(key);
 
-		if (!strcmp(key + (i - 2), "\r\n"))
-			key[i - 2] = '\0';
-		lj_debug(3, "[%s]\n", key);
-#endif
+			if (!strcmp(key + (i - 2), "\r\n"))
+				key[i - 2] = '\0';
+			lj_debug(3, "[%s]\n", key);
+		}
 	}
 
 	/*
@@ -131,12 +143,13 @@ lj_send_request(const lj_server * const serverinfo, const lj_user * const user,
 	 * 1024 bytes.  REVISIT THIS
 	 */
 	while (fgets(key, LJ_BUFFER_MAX, conn)
-	       && fgets(value, LJ_BUFFER_MAX, conn))
+			&& fgets(value, LJ_BUFFER_MAX, conn))
 	{
 		chomp(key);
 		chomp(value);
-		lj_debug(3, "Putting [%s]->[%s]...", key, value);
-		put(lj_hash, key, value);
+		lj_chardecode(value, decoded);
+		lj_debug(1, "Putting [%s]->[%s]...\n", key, decoded);
+		put(lj_hash, key, decoded);
 	}
 
 	closeconn(conn);
